@@ -1,5 +1,5 @@
-#ifndef __8MR191_1_4209_E4
-#define __8MR191_1_4209_E4
+#ifndef __8MR151_30_E4
+#define __8MR151_30_E4
 
 #include <string.h>
 
@@ -10,18 +10,18 @@
 #endif
 
 
-#define 8MR191_1_4209_E4_BUILDER_VERSION_MAJOR  0
-#define 8MR191_1_4209_E4_BUILDER_VERSION_MINOR  9
-#define 8MR191_1_4209_E4_BUILDER_VERSION_BUGFIX 16
-#define 8MR191_1_4209_E4_BUILDER_VERSION_SUFFIX ""
-#define 8MR191_1_4209_E4_BUILDER_VERSION        "0.9.16"
+#define 8MR151_30_E4_BUILDER_VERSION_MAJOR  0
+#define 8MR151_30_E4_BUILDER_VERSION_MINOR  9
+#define 8MR151_30_E4_BUILDER_VERSION_BUGFIX 16
+#define 8MR151_30_E4_BUILDER_VERSION_SUFFIX ""
+#define 8MR151_30_E4_BUILDER_VERSION        "0.9.16"
 
 
 #if defined(_MSC_VER)
 #define inline __inline
 #endif
 
-static inline result_t set_profile_8MR191_1_4209_E4(device_t id)
+static inline result_t set_profile_8MR151_30_E4(device_t id)
 {
   result_t worst_result = result_ok;
   result_t result = result_ok;
@@ -29,7 +29,7 @@ static inline result_t set_profile_8MR191_1_4209_E4(device_t id)
   feedback_settings_t feedback_settings;
   memset((void*)&feedback_settings, 0, sizeof(feedback_settings_t));
   feedback_settings.IPS = 4000;
-  feedback_settings.FeedbackType = FEEDBACK_NONE;
+  feedback_settings.FeedbackType = FEEDBACK_EMF;
   feedback_settings.FeedbackFlags = FEEDBACK_ENC_TYPE_SINGLE_ENDED | FEEDBACK_ENC_TYPE_AUTO;
   feedback_settings.CountsPerTurn = 4000;
   result = set_feedback_settings(id, &feedback_settings);
@@ -48,9 +48,9 @@ static inline result_t set_profile_8MR191_1_4209_E4(device_t id)
   home_settings.uFastHome = 0;
   home_settings.SlowHome = 10;
   home_settings.uSlowHome = 0;
-  home_settings.HomeDelta = -1000;
+  home_settings.HomeDelta = -1250;
   home_settings.uHomeDelta = 0;
-  home_settings.HomeFlags = HOME_USE_FAST | HOME_STOP_SECOND_REV | HOME_STOP_FIRST_BITS | HOME_MV_SEC_EN | HOME_DIR_FIRST;
+  home_settings.HomeFlags = HOME_USE_FAST | HOME_STOP_SECOND_REV | HOME_STOP_FIRST_BITS | HOME_MV_SEC_EN | HOME_DIR_SECOND;
   result = set_home_settings(id, &home_settings);
 
   if (result != result_ok)
@@ -63,11 +63,11 @@ static inline result_t set_profile_8MR191_1_4209_E4(device_t id)
 
   move_settings_t move_settings;
   memset((void*)&move_settings, 0, sizeof(move_settings_t));
-  move_settings.Speed = 1000;
+  move_settings.Speed = 2000;
   move_settings.uSpeed = 0;
   move_settings.Accel = 2000;
-  move_settings.Decel = 4000;
-  move_settings.AntiplaySpeed = 1000;
+  move_settings.Decel = 5000;
+  move_settings.AntiplaySpeed = 2000;
   move_settings.uAntiplaySpeed = 0;
   move_settings.MoveFlags = 0;
   result = set_move_settings(id, &move_settings);
@@ -82,14 +82,14 @@ static inline result_t set_profile_8MR191_1_4209_E4(device_t id)
 
   engine_settings_t engine_settings;
   memset((void*)&engine_settings, 0, sizeof(engine_settings_t));
-  engine_settings.NomVoltage = 1;
+  engine_settings.NomVoltage = 360;
   engine_settings.NomCurrent = 670;
   engine_settings.NomSpeed = 5000;
   engine_settings.uNomSpeed = 0;
   engine_settings.EngineFlags = ENGINE_LIMIT_RPM | ENGINE_ACCEL_ON;
-  engine_settings.Antiplay = 575;
+  engine_settings.Antiplay = 1800;
   engine_settings.MicrostepMode = MICROSTEP_MODE_FRAC_256;
-  engine_settings.StepsPerRev = 400;
+  engine_settings.StepsPerRev = 200;
   result = set_engine_settings(id, &engine_settings);
 
   if (result != result_ok)
@@ -120,7 +120,7 @@ static inline result_t set_profile_8MR191_1_4209_E4(device_t id)
   power_settings.CurrReductDelay = 1000;
   power_settings.PowerOffDelay = 60;
   power_settings.CurrentSetTime = 300;
-  power_settings.PowerFlags = POWER_SMOOTH_CURRENT | POWER_OFF_ENABLED | POWER_REDUCT_ENABLED;
+  power_settings.PowerFlags = POWER_SMOOTH_CURRENT | POWER_REDUCT_ENABLED;
   result = set_power_settings(id, &power_settings);
 
   if (result != result_ok)
@@ -154,10 +154,10 @@ static inline result_t set_profile_8MR191_1_4209_E4(device_t id)
   edges_settings_t edges_settings;
   memset((void*)&edges_settings, 0, sizeof(edges_settings_t));
   edges_settings.BorderFlags = 0;
-  edges_settings.EnderFlags = ENDER_SW2_ACTIVE_LOW | ENDER_SW1_ACTIVE_LOW | ENDER_SWAP;
-  edges_settings.LeftBorder = -69200;
+  edges_settings.EnderFlags = 0;
+  edges_settings.LeftBorder = -33850;
   edges_settings.uLeftBorder = 0;
-  edges_settings.RightBorder = -800;
+  edges_settings.RightBorder = 350;
   edges_settings.uRightBorder = 0;
   result = set_edges_settings(id, &edges_settings);
 
@@ -174,8 +174,8 @@ static inline result_t set_profile_8MR191_1_4209_E4(device_t id)
   pid_settings.KpU = 0;
   pid_settings.KiU = 0;
   pid_settings.KdU = 0;
-  pid_settings.Kpf = 0.003599999938160181;
-  pid_settings.Kif = 0.03799999877810478;
+  pid_settings.Kpf = 0.006000000052154064;
+  pid_settings.Kif = 0.05000000074505806;
   pid_settings.Kdf = 2.8000000384054147e-05;
   result = set_pid_settings(id, &pid_settings);
 
@@ -255,9 +255,9 @@ static inline result_t set_profile_8MR191_1_4209_E4(device_t id)
 
   control_settings_t control_settings;
   memset((void*)&control_settings, 0, sizeof(control_settings_t));
-  control_settings.MaxSpeed[0] = 100;
-  control_settings.MaxSpeed[1] = 1000;
-  control_settings.MaxSpeed[2] = 0;
+  control_settings.MaxSpeed[0] = 20;
+  control_settings.MaxSpeed[1] = 200;
+  control_settings.MaxSpeed[2] = 2000;
   control_settings.MaxSpeed[3] = 0;
   control_settings.MaxSpeed[4] = 0;
   control_settings.MaxSpeed[5] = 0;
@@ -311,7 +311,7 @@ static inline result_t set_profile_8MR191_1_4209_E4(device_t id)
   ctp_settings_t ctp_settings;
   memset((void*)&ctp_settings, 0, sizeof(ctp_settings_t));
   ctp_settings.CTPMinError = 3;
-  ctp_settings.CTPFlags = CTP_BASE | CTP_ENABLED;
+  ctp_settings.CTPFlags = CTP_BASE;
   result = set_ctp_settings(id, &ctp_settings);
 
   if (result != result_ok)
@@ -353,9 +353,9 @@ static inline result_t set_profile_8MR191_1_4209_E4(device_t id)
 
   emf_settings_t emf_settings;
   memset((void*)&emf_settings, 0, sizeof(emf_settings_t));
-  emf_settings.L = 0;
-  emf_settings.R = 0;
-  emf_settings.Km = 0;
+  emf_settings.L = 0.005400000140070915;
+  emf_settings.R = 7.400000095367432;
+  emf_settings.Km = 0.0024999999441206455;
   emf_settings.BackEMFFlags = BACK_EMF_KM_AUTO | BACK_EMF_RESISTANCE_AUTO | BACK_EMF_INDUCTANCE_AUTO;
   result = set_emf_settings(id, &emf_settings);
 
@@ -411,9 +411,9 @@ static inline result_t set_profile_8MR191_1_4209_E4(device_t id)
 
   stage_information_t stage_information;
   memset((void*)&stage_information, 0, sizeof(stage_information_t));
-  const int8_t stage_information_Manufacturer_temp[16] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
+  const int8_t stage_information_Manufacturer_temp[16] = {0, 116, 97, 110, 100, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
   memcpy(stage_information.Manufacturer, stage_information_Manufacturer_temp, sizeof(int8_t) * 16);
-  const int8_t stage_information_PartNumber_temp[24] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
+  const int8_t stage_information_PartNumber_temp[24] = {56, 77, 82, 49, 53, 49, 45, 51, 48, 45, 69, 52, 0, 0, 0, 0, 0, 52, 48, 68, 45, 69, 65, 83};
   memcpy(stage_information.PartNumber, stage_information_PartNumber_temp, sizeof(int8_t) * 24);
   result = set_stage_information(id, &stage_information);
 
@@ -427,11 +427,11 @@ static inline result_t set_profile_8MR191_1_4209_E4(device_t id)
 
   stage_settings_t stage_settings;
   memset((void*)&stage_settings, 0, sizeof(stage_settings_t));
-  stage_settings.LeadScrewPitch = 0;
-  const int8_t stage_settings_Units_temp[8] = {0, 0, 0, 0, 0, 0, 0, 0};
+  stage_settings.LeadScrewPitch = 2;
+  const int8_t stage_settings_Units_temp[8] = {0, 109, 0, 114, 101, 101, 0, 0};
   memcpy(stage_settings.Units, stage_settings_Units_temp, sizeof(int8_t) * 8);
-  stage_settings.MaxSpeed = 0;
-  stage_settings.TravelRange = 0;
+  stage_settings.MaxSpeed = 50;
+  stage_settings.TravelRange = 360;
   stage_settings.SupplyVoltageMin = 0;
   stage_settings.SupplyVoltageMax = 0;
   stage_settings.MaxCurrentConsumption = 0;
@@ -449,9 +449,9 @@ static inline result_t set_profile_8MR191_1_4209_E4(device_t id)
 
   motor_information_t motor_information;
   memset((void*)&motor_information, 0, sizeof(motor_information_t));
-  const int8_t motor_information_Manufacturer_temp[16] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
+  const int8_t motor_information_Manufacturer_temp[16] = {0, 97, 120, 111, 110, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
   memcpy(motor_information.Manufacturer, motor_information_Manufacturer_temp, sizeof(int8_t) * 16);
-  const int8_t motor_information_PartNumber_temp[24] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
+  const int8_t motor_information_PartNumber_temp[24] = {0, 67, 45, 105, 45, 52, 48, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
   memcpy(motor_information.PartNumber, motor_information_PartNumber_temp, sizeof(int8_t) * 24);
   result = set_motor_information(id, &motor_information);
 
@@ -465,7 +465,7 @@ static inline result_t set_profile_8MR191_1_4209_E4(device_t id)
 
   motor_settings_t motor_settings;
   memset((void*)&motor_settings, 0, sizeof(motor_settings_t));
-  motor_settings.MotorType = MOTOR_TYPE_UNKNOWN;
+  motor_settings.MotorType = MOTOR_TYPE_STEP | MOTOR_TYPE_UNKNOWN;
   motor_settings.ReservedField = 0;
   motor_settings.Poles = 0;
   motor_settings.Phases = 0;
@@ -483,7 +483,7 @@ static inline result_t set_profile_8MR191_1_4209_E4(device_t id)
   motor_settings.SpeedConstant = 0;
   motor_settings.SpeedTorqueGradient = 0;
   motor_settings.MechanicalTimeConstant = 0;
-  motor_settings.MaxSpeed = 0;
+  motor_settings.MaxSpeed = 5000;
   motor_settings.MaxCurrent = 0;
   motor_settings.MaxCurrentTime = 0;
   motor_settings.NoLoadCurrent = 0;
@@ -500,9 +500,9 @@ static inline result_t set_profile_8MR191_1_4209_E4(device_t id)
 
   encoder_information_t encoder_information;
   memset((void*)&encoder_information, 0, sizeof(encoder_information_t));
-  const int8_t encoder_information_Manufacturer_temp[16] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
+  const int8_t encoder_information_Manufacturer_temp[16] = {0, 97, 120, 111, 110, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
   memcpy(encoder_information.Manufacturer, encoder_information_Manufacturer_temp, sizeof(int8_t) * 16);
-  const int8_t encoder_information_PartNumber_temp[24] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
+  const int8_t encoder_information_PartNumber_temp[24] = {0, 54, 45, 69, 65, 83, 89, 45, 49, 48, 50, 52, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
   memcpy(encoder_information.PartNumber, encoder_information_PartNumber_temp, sizeof(int8_t) * 24);
   result = set_encoder_information(id, &encoder_information);
 
@@ -520,7 +520,7 @@ static inline result_t set_profile_8MR191_1_4209_E4(device_t id)
   encoder_settings.SupplyVoltageMin = 0;
   encoder_settings.SupplyVoltageMax = 0;
   encoder_settings.MaxCurrentConsumption = 0;
-  encoder_settings.PPR = 0;
+  encoder_settings.PPR = 1000;
   encoder_settings.EncoderSettings = 0;
   result = set_encoder_settings(id, &encoder_settings);
 
@@ -583,8 +583,8 @@ static inline result_t set_profile_8MR191_1_4209_E4(device_t id)
 
   gear_settings_t gear_settings;
   memset((void*)&gear_settings, 0, sizeof(gear_settings_t));
-  gear_settings.ReductionIn = 0;
-  gear_settings.ReductionOut = 0;
+  gear_settings.ReductionIn = 1;
+  gear_settings.ReductionOut = 1;
   gear_settings.RatedInputTorque = 0;
   gear_settings.RatedInputSpeed = 0;
   gear_settings.MaxOutputBacklash = 0;
@@ -613,7 +613,7 @@ static inline result_t set_profile_8MR191_1_4209_E4(device_t id)
   accessories_settings.TSMin = 0;
   accessories_settings.TSMax = 0;
   accessories_settings.TSGrad = 0;
-  accessories_settings.TSSettings = TS_TYPE_UNKNOWN;
+  accessories_settings.TSSettings = TS_TYPE_THERMOCOUPLE | TS_TYPE_UNKNOWN;
   accessories_settings.LimitSwitchesSettings = 0;
   result = set_accessories_settings(id, &accessories_settings);
 
